<?php
/************************************************************************
 * This file is part of EspoCRM.
 *
 * EspoCRM - Open Source CRM application.
 * Copyright (C) 2014  Yuri Kuznetsov, Taras Machyshyn, Oleksiy Avramenko
 * Website: http://www.espocrm.com
 *
 * EspoCRM is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * EspoCRM is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with EspoCRM. If not, see http://www.gnu.org/licenses/.
 ************************************************************************/

class BeforeUpgrade
{
    public function run($container)
    {
        $this->checkMySQLVersion($container);

        $entityManager = $container->get('entityManager');

        $roleList = $entityManager->getRepository('Role')->find();
        foreach ($roleList as $role) {
            $data = $role->get('data');
            if ($data && isset($data->User) && is_object($data->User)) {
                $data = clone($data);
                $data->User->edit = 'no';
                $role->set('data', $data);
                $entityManager->saveEntity($role);
            }
        }
    }

    protected function checkMySQLVersion($container)
    {
        $pdo = $container->get('entityManager')->getPDO();

        $query = "SHOW VARIABLES LIKE 'version'";
        $sth = $pdo->prepare($query);
        $sth->execute();

        $row = $sth->fetch(\PDO::FETCH_ASSOC);

        if (empty($row['Value'])) {
            return;
        }

        $currentMysqlVersion = $row['Value'];

        if (version_compare($currentMysqlVersion, '5.5.3') == -1) {
            throw new \Espo\Core\Exceptions\Error('Your MySQL version is not supported. Please use MySQL 5.5.3 at least.');
        }
    }
}
